@@ -70,7 +70,7 @@ GAMBoostModel <- function(
     gridinfo = new_gridinfo(
       param = "mstop",
       get_values = c(
-        function(n, ...) round(seq_range(0, 50, c(1, 1000), n + 1))
+        function(n, ...) round_int(seq_range(0, 50, c(1, 1000), n + 1))
       )
     ),
 
@@ -96,7 +96,7 @@ GAMBoostModel <- function(
         )
       }
       mboost::gamboost(
-        formula, data = as.data.frame(data), na.action = na.pass,
+        formula, data = as.data.frame(formula, data), na.action = na.pass,
         weights = weights, family = family, baselearner = baselearner,
         dfbase = dfbase, control = mboost::boost_control(...)
       )
