@@ -307,7 +307,7 @@ MLModelFunction(XGBTreeModel) <- NULL
               "subsample", "colsample_bytree", "rate_drop", "skip_drop",
               "alpha", "lambda"),
     get_values = c(
-      function(n, ...) round(seq_range(0, 50, c(1, 1000), n + 1)),
+      function(n, ...) round_int(seq_range(0, 50, c(1, 1000), n + 1)),
       function(n, ...) seq(0.001, 0.6, length = n),
       function(n, ...) seq(0, 10, length = n),
       function(n, ...) seq_len(min(n, 10)),
