@@ -46,7 +46,7 @@
 #' }
 #'
 calibration <- function(
-  x, y = NULL, weights = NULL, breaks = 10, span = 0.75, distr = NULL,
+  x, y = NULL, weights = NULL, breaks = 10, span = 0.75, distr = character(),
   na.rm = TRUE, ...
 ) {
   if (na.rm) {
@@ -57,7 +57,7 @@ calibration <- function(
   }
   Calibration(
     .calibration(x, y, weights, breaks = breaks, span = span, distr = distr),
-    smoothed = is.null(breaks)
+    smoothed = is_empty(breaks)
   )
 }
 
@@ -67,7 +67,9 @@ Calibration <- function(object, ..., .check = TRUE) {
     if (is.null(object$Model)) object$Model <- factor("Model")
     missing <- missing_names(c("Response", "Predicted", "Observed"), object)
     if (length(missing)) {
-      throw(Error(label_items("missing calibration variable", missing)))
+      throw(Error(note_items(
+        "Missing calibration variable{?s}: ", missing, "."
+      )))
     }
   }
   rownames(object) <- NULL
@@ -82,7 +84,7 @@ setGeneric(".calibration",
 
 setMethod(".calibration", c("ANY", "ANY"),
   function(observed, predicted, ...) {
-    throw(Error("calibration unavailable for response type"))
+    throw(Error("Calibration unavailable for response type."))
   }
 )
 
@@ -91,7 +93,7 @@ setMethod(".calibration", c("factor", "matrix"),
   function(observed, predicted, ...) {
     cal <- .calibration(model.matrix(~ observed - 1), predicted, ...)
     bounds <- c("Lower", "Upper")
-    cal$Observed[, bounds] <- pmin(pmax(0, cal$Observed[, bounds]), 1)
+    cal$Observed[, bounds] <- pmin(pmax(cal$Observed[, bounds], 0), 1)
     cal
   }
 )
@@ -102,7 +104,7 @@ setMethod(".calibration", c("factor", "numeric"),
     observed <- as.numeric(observed == levels(observed)[2])
     cal <- .calibration(observed, predicted, ...)
     bounds <- c("Lower", "Upper")
-    cal$Observed[, bounds] <- pmin(pmax(0, cal$Observed[, bounds]), 1)
+    cal$Observed[, bounds] <- pmin(pmax(cal$Observed[, bounds], 0), 1)
     cal
   }
 )
@@ -115,14 +117,14 @@ setMethod(".calibration", c("matrix", "matrix"),
     df <- data.frame(Response = rep(factor(colnames(predicted)),
                                     each = nrow(predicted)),
                      Predicted = as.numeric(predicted))
-    if (is.null(breaks)) {
+    if (is_empty(breaks)) {
       loessfit_list <- map(function(i) {
         y <- observed[, i]
         x <- predicted[, i]
         predict(loess(y ~ x, weights = weights, span = span), se = TRUE)
       }, seq_len(ncol(predicted)))
-      Mean <- c(map_num(getElement, loessfit_list, "fit"))
-      SE <- c(map_num(getElement, loessfit_list, "se.fit"))
+      Mean <- c(map("num", getElement, loessfit_list, "fit"))
+      SE <- c(map("num", getElement, loessfit_list, "se.fit"))
       df$Observed <- cbind(Mean = Mean, SE = SE,
                            Lower = Mean - SE,
                            Upper = Mean + SE)
@@ -153,7 +155,7 @@ setMethod(".calibration", c("numeric", "numeric"),
 )
 
 
-setMethod(".calibration", c("Resamples", "ANY"),
+setMethod(".calibration", c("Resample", "ANY"),
   function(observed, predicted, weights, ...) {
     cal_list <- by(observed, observed$Model, function(resample) {
       calibration(resample$Observed, resample$Predicted, resample$Weight,
@@ -172,10 +174,10 @@ setMethod(".calibration", c("Surv", "SurvProbs"),
     df <- data.frame(Response = rep(factor(colnames(predicted)),
                                     each = nrow(predicted)),
                      Predicted = as.numeric(predicted))
-    if (is.null(breaks)) {
+    if (is_empty(breaks)) {
       throw(check_censoring(observed, "right"))
       throw(check_equal_weights(weights))
-      Mean <- c(map_num(function(i) {
+      Mean <- c(map("num", function(i) {
         x <- predicted[, i]
         harefit <- polspline::hare(observed[, "time"], observed[, "status"], x)
         1 - polspline::phare(times[i], x, harefit)
@@ -194,7 +196,7 @@ setMethod(".calibration", c("Surv", "SurvProbs"),
         SE <- c(0, km$std.err)[interval]
         result <- data[1, c("Response", "Predicted")]
         result$Observed <- cbind(Mean = Mean, SE = SE,
-                                 Lower = max(0, Mean - SE),
+                                 Lower = max(Mean - SE, 0),
                                  Upper = min(Mean + SE, 1))
         result
       }, simplify = FALSE)
@@ -224,7 +226,7 @@ setMethod(".calibration", c("Surv", "numeric"),
       list(Mean = est$fit[[1]], SE = est$se.fit[[1]])
     }
 
-    if (is.null(breaks)) {
+    if (is_empty(breaks)) {
       df <- data.frame(
         Response = factor("Mean"),
         Predicted = unique(predicted)
@@ -232,7 +234,7 @@ setMethod(".calibration", c("Surv", "numeric"),
       tricubic <- function(x, span = 1, min_weight = 0) {
         x <- abs(x)
         x_range <- span * diff(range(x))
-        (1 - min_weight) * pmax(0, (1 - (x / x_range)^3)^3) + min_weight
+        (1 - min_weight) * pmax((1 - (x / x_range)^3)^3, 0) + min_weight
       }
       metrics_list <- map(function(value) {
         weights <- weights * tricubic(predicted - value, span = span,
@@ -243,7 +245,7 @@ setMethod(".calibration", c("Surv", "numeric"),
           survreg_est(observed, distr, weights)
         }
         with(est, c(Mean = Mean, SE = SE,
-                    Lower = max(0, Mean - SE),
+                    Lower = max(Mean - SE, 0),
                     Upper = Mean + SE))
       }, df$Predicted)
       df$Observed <- do.call(rbind, metrics_list)
@@ -267,7 +269,7 @@ setMethod(".calibration", c("Surv", "numeric"),
         }
         result <- data[1, c("Response", "Predicted")]
         result$Observed <- with(est, cbind(Mean = Mean, SE = SE,
-                                           Lower = max(0, Mean - SE),
+                                           Lower = max(Mean - SE, 0),
                                            Upper = Mean + SE))
         result
       }, simplify = FALSE)
@@ -280,7 +282,7 @@ setMethod(".calibration", c("Surv", "numeric"),
 midpoints <- function(x, breaks) {
   breaks <- if (length(breaks) == 1) {
     break_range <- range(x, na.rm = TRUE, finite = TRUE)
-    num_breaks <- max(1, as.integer(breaks)) + 1
+    num_breaks <- max(as.integer(breaks), 1) + 1
     seq(break_range[1], break_range[2], length = num_breaks)
   } else {
     sort(breaks)
