@@ -145,22 +145,25 @@ expand_modelgrid.recipe <- function(input, model, info = FALSE, ...) {
 #'
 expand_modelgrid.ModelSpecification <- function(object, ...) {
   grid <- object@grid
+
   if (is_empty(grid)) {
-    map_slots(function(object) {
-      types <- c("ModeledInput", "SelectedInput", "SelectedModel")
-      found <- map("logi", is, list(object), types)
-      if (any(found)) {
-        throw(Error(
-          "Cannot expand the tuning grids of a ModelSpecification containing ",
-          types[found], "."
-        ))
-      }
-    }, object)
+
+    types <- c("ModeledInput", "SelectedInputOrModel")
+    found <- unique(unlist(map_slots(function(slot) {
+      types[map("logi", is, list(slot), types)]
+    }, object)))
+    if (length(found)) {
+      throw(Warning(
+        "Cannot expand the tuning grids of a ModelSpecification containing ",
+        as_string(found, conj = "or"), "."
+      ))
+      return(NULL)
+    }
 
     get_modelgrids <- function(input) {
       map_slots(function(model) {
         get_grid(model, input)$params
-      }, object, names = c("model", "models"))
+      }, object, names = c("model", "candidates"))
     }
 
     make_grid <- function(grids) {
@@ -169,7 +172,7 @@ expand_modelgrid.ModelSpecification <- function(object, ...) {
 
     input_grid <- make_grid(map_slots(function(input) {
       get_grid(input)$params
-    }, object, names = c("input", "inputs")))
+    }, object, names = c("input", "candidates")))
 
     if (nrow(input_grid)) {
       grid <- NULL
@@ -181,7 +184,9 @@ expand_modelgrid.ModelSpecification <- function(object, ...) {
     } else {
       grid <- make_grid(get_modelgrids(object@input))
     }
+
   }
+
   grid
 }
 
