@@ -51,9 +51,9 @@ setMethod("[", c(x = "ModelFrame", i = "ANY", j = "ANY", drop = "ANY"),
     if (identical(colnames(x), colnames(y))) {
       y <- ModelFrame(terms(x), y, na.rm = FALSE)
       if (is(x, "ModeledInput")) {
-        y <- new(class(x), y, model = x@model)
+        y <- ModelSpecification(y, model = as.MLModel(x), control = NULL)
       } else if (is(x, "SelectedInput")) {
-        y <- new(class(x), y, inputs = x@inputs, params = x@params)
+        y <- new(class(x), y, candidates = x@candidates, params = x@params)
       }
     }
     y
