@@ -68,15 +68,19 @@ modelinfo <- function(...) {
 
 
 .modelinfo.character <- function(x, ...) {
-  model <- try(as.MLModel(x), silent = TRUE)
-  if (is(model, "try-error")) model <- list()
+  model <- tryCatch(
+    as.MLModel(x),
+    error = function(cond) list()
+  )
   .modelinfo(model, ...)
 }
 
 
 .modelinfo.function <- function(x, ...) {
-  model <- try(as.MLModel(x), silent = TRUE)
-  if (is(model, "try-error")) model <- list()
+  model <- tryCatch(
+    as.MLModel(x),
+    error = function(cond) list()
+  )
   .modelinfo(model, ...)
 }
 
