@@ -8,6 +8,7 @@
 #' @param x object to print.
 #' @param n integer number of models or data frame rows to show.
 #' @param id logical indicating whether to show object identifiers.
+#' @param data logical indicating whether to show model data.
 #' @param ... arguments passed to other methods, including the one described
 #'   below.
 #'   \describe{
@@ -115,7 +116,7 @@ print.EnsembleModel <- function(
     hline(level)
     print_train_label("Models:")
     newline()
-    print(x@models, n = n, level = nextlevel, id = id)
+    print(x@candidates, n = n, level = nextlevel, id = id)
     hline(level)
     print(x@params, n = n, level = nextlevel)
     if (trained) {
@@ -125,7 +126,7 @@ print.EnsembleModel <- function(
   } else if (level == 1) {
     newline()
     print_train_label("Models:")
-    print(x@models, n = n, level = nextlevel, id = id)
+    print(x@candidates, n = n, level = nextlevel, id = id)
   }
   invisible(x)
 }
@@ -283,19 +284,14 @@ setShowDefault("MLOptimization")
 #' @rdname print-methods
 #'
 print.ModelFrame <- function(
-  x, n = MachineShop::settings("print_max"), id = FALSE, ...
+  x, n = MachineShop::settings("print_max"), id = FALSE, data = TRUE, ...
 ) {
   title(x, ...)
   level <- nesting_level(...)
   if (id) print_id(x)
   label <- if (level < 2) style_label("Terms: ")
   print_items(formula(x), n = n, label = label)
-  if (level < 1) {
-    print_label("Data:")
-    print_items(within(as(x, "data.frame"), remove("(names)")), n = n)
-  } else if (level == 1) {
-    print_fields(list("Number of observations: " = nrow(x)))
-  }
+  if (data) print_data(as(x, "data.frame"), n = n, level = level)
   invisible(x)
 }
 
@@ -306,7 +302,7 @@ setShowDefault("ModelFrame")
 #' @rdname print-methods
 #'
 print.ModelRecipe <- function(
-  x, n = MachineShop::settings("print_max"), id = FALSE, ...
+  x, n = MachineShop::settings("print_max"), id = FALSE, data = TRUE, ...
 ) {
   title(x, ...)
   level <- nesting_level(...)
@@ -328,13 +324,8 @@ print.ModelRecipe <- function(
       add_names = TRUE, n = n
     )
   }
-  if (level < 1) {
-    print_fields(list("Tuning grid: " = has_grid(x)))
-    print_label("Data:")
-    print_items(within(x$template, remove("(names)")), n = n)
-  } else if (level == 1) {
-    print_fields(list("Number of observations: " = nrow(x$template)))
-  }
+  if (level < 1) print_fields(list("Tuning grid: " = has_grid(x)))
+  if (data) print_data(x$template, n = n, level = level)
   invisible(x)
 }
 
@@ -345,15 +336,21 @@ setShowDefault("ModelRecipe")
 #' @rdname print-methods
 #'
 print.ModelSpecification <- function(
-  x, n = MachineShop::settings("print_max"), ...
+  x, n = MachineShop::settings("print_max"), id = FALSE, ...
 ) {
   title(x, ...)
   level <- nesting_level(...)
   nextlevel <- level + 1
+  if (id) {
+    print_id(x)
+    newline()
+  }
   show_all <- length(x@grid) && level < 1
   print(x@input, n = n, level = nextlevel, id = show_all)
-  newline()
-  print(x@model, n = n, level = nextlevel, id = show_all)
+  if (!is(x@model, "NullModel")) {
+    newline()
+    print(x@model, n = n, level = nextlevel, id = show_all)
+  }
   if (show_all) {
     newline()
     heading("Grid", level = nextlevel)
@@ -384,17 +381,6 @@ print.ModeledInput <- function(x, n = MachineShop::settings("print_max"), ...) {
 }
 
 
-print.ModeledTerms <- function(x, n = MachineShop::settings("print_max"), ...) {
-  level <- nesting_level(...)
-  print_items(formula(x), n = n)
-  if (level < 2) {
-    newline()
-    print(x@model, n = n, level = level + 1)
-  }
-  invisible(x)
-}
-
-
 print.ParameterGrid <- function(x, ...) {
   NextMethod()
   newline()
@@ -517,13 +503,13 @@ print.SelectedInput <- function(
     hline(level)
     print_train_label("Selection set:")
     newline()
-    print(x@inputs, n = n, level = nextlevel, id = id)
+    print(x@candidates, n = n, level = nextlevel, id = id, data = FALSE)
     hline(level)
     print(x@params, n = n, level = nextlevel)
   } else if (level == 1) {
     newline()
     print_train_label("Selection set:")
-    print(x@inputs, n = n, level = nextlevel, id = id)
+    print(x@candidates, n = -n, level = nextlevel, id = id, data = FALSE)
   }
   invisible(x)
 }
@@ -762,8 +748,10 @@ nesting_level <- function(level = 0, ...) {
 }
 
 
-new_print_progress <- function(start_time = Sys.time()) {
-  eval(bquote(function(...) print_progress(..., start_time = .(start_time))))
+new_print_progress <- function() {
+  res <- function(...) NULL
+  body(res) <- bquote(print_progress(..., start_time = .(Sys.time())))
+  res
 }
 
 
@@ -801,6 +789,16 @@ print_control <- function(x, fields = NULL, n = Inf, ...) {
 }
 
 
+print_data <- function(x, n = Inf, level = 0) {
+  if (level < 1) {
+    print_label("Data:")
+    print_items(within(x, remove("(names)")), n = n)
+  } else if (level == 1) {
+    print_fields(list("Number of observations: " = nrow(x)))
+  }
+}
+
+
 print_default <- function(x, max = NULL, ...) {
   if (identical(max, Inf)) max <- .Machine$integer.max
   print(x, max = max, ...)
@@ -875,28 +873,11 @@ print_items.formula <- function(x, exdent = 2, ...) {
   x <- deparse1(x)
   split <- regexpr("[+]", x)
   if (split > 0) x <- c(substring(x, 1, split - 1), substring(x, split + 1))
-  print_items(x, exdent = exdent, sep = "+", ...)
+  print_items(x, exdent = exdent, sep = " + ", ...)
 }
 
 
-print_items.list <- function(x, n = Inf, ...) {
-  diff <- length(x) - n
-  if (diff > 0) {
-    print_default(head(x, n), max = n)
-    if (is.null(names(x))) names(x) <- seq_along(x)
-    extra <- tail(names(x), diff)
-    msg <- pluralize(
-      "... with ", format_len(diff), " more element{?s}: ", "{qty(diff)}"
-    )
-    print_items(extra, label = msg, n = n, style = style_extra)
-    newline()
-  } else {
-    print_default(x, max = n)
-  }
-}
-
-
-print_items.ListOf <- function(x, n = Inf, level = 0, id = FALSE, ...) {
+print_items.ListOf <- function(x, n = Inf, level = 0, ...) {
   if (is_empty(x)) {
     hline(level, label = "ListOf()")
   } else {
@@ -910,7 +891,7 @@ print_items.ListOf <- function(x, n = Inf, level = 0, id = FALSE, ...) {
       }
       if (i <= n) {
         hline(level, label = paste0(prefix, label))
-        print(x[[i]], n = n, level = level, id = id, na.print = NULL)
+        print(x[[i]], n = n, level = level, na.print = NULL, ...)
         if (level < 2) newline()
       }
       label
