@@ -232,6 +232,7 @@ MachineShop_global <- as.environment(list(
         "mse",
         "msle",
         "npv",
+        "ppr",
         "ppv",
         "pr_auc",
         "precision",
@@ -241,7 +242,6 @@ MachineShop_global <- as.environment(list(
         "rmsle",
         "roc_auc",
         "roc_index",
-        "rpp",
         "sensitivity",
         "specificity",
         "tnr",
