@@ -108,17 +108,16 @@ varimp <- function(object, method = c("permute", "model"), scale = TRUE, ...) {
   model <- as.MLModel(object)
   throw(check_packages(model@packages))
 
-  if (missing(method)) {
-    throw(Warning(
-      "The default method has changed from \"model\" to \"permute\"; ",
-      "set 'method = \"model\"' to revert to the previous behavior."
-    ), times = 3)
-  }
-
   switch(match.arg(method),
     "model" = {
       vi <- model@varimp(unMLModelFit(object), ...)
-      if (is.null(vi)) vi <- varimp_permute(object)
+      if (is.null(vi)) {
+        throw(Warning(
+          "Model-specific variable importance is not available; ",
+          "computing permutation-based importance instead."
+        ))
+        vi <- varimp_permute(object)
+      }
     },
     "permute" = {
       args <- eval(substitute(alist(object, ...)))
